# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class UpstreamGroupMappingEntry(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'priority': 'int',
        'upstream_group_name': 'str',
        'upstream_name_is_a_guid': 'bool',
        'agilicus_group_name': 'str',
        'group_org_id': 'str'
    }

    attribute_map = {
        'priority': 'priority',
        'upstream_group_name': 'upstream_group_name',
        'upstream_name_is_a_guid': 'upstream_name_is_a_guid',
        'agilicus_group_name': 'agilicus_group_name',
        'group_org_id': 'group_org_id'
    }

    def __init__(self, priority=None, upstream_group_name=None, upstream_name_is_a_guid=None, agilicus_group_name=None, group_org_id=None, local_vars_configuration=None):  # noqa: E501
        """UpstreamGroupMappingEntry - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._priority = None
        self._upstream_group_name = None
        self._upstream_name_is_a_guid = None
        self._agilicus_group_name = None
        self._group_org_id = None
        self.discriminator = None

        self.priority = priority
        self.upstream_group_name = upstream_group_name
        if upstream_name_is_a_guid is not None:
            self.upstream_name_is_a_guid = upstream_name_is_a_guid
        self.agilicus_group_name = agilicus_group_name
        if group_org_id is not None:
            self.group_org_id = group_org_id

    @property
    def priority(self):
        """Gets the priority of this UpstreamGroupMappingEntry.  # noqa: E501

        The priority of the mapping entry. A lower number indicates a higher priority.  # noqa: E501

        :return: The priority of this UpstreamGroupMappingEntry.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this UpstreamGroupMappingEntry.

        The priority of the mapping entry. A lower number indicates a higher priority.  # noqa: E501

        :param priority: The priority of this UpstreamGroupMappingEntry.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and priority is None:  # noqa: E501
            raise ValueError("Invalid value for `priority`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                priority is not None and priority < 1):  # noqa: E501
            raise ValueError("Invalid value for `priority`, must be a value greater than or equal to `1`")  # noqa: E501

        self._priority = priority

    @property
    def upstream_group_name(self):
        """Gets the upstream_group_name of this UpstreamGroupMappingEntry.  # noqa: E501

        The name of the group in your upstream identity provider that you want to map. This can be in the form of a regular expression capture group. The example value will capture all groups starting with 'Company Team' and will use the value in the agilicus_group_name. For example Company Team HR Group will be mapped to Agilicus HR Group when the agilicus_group_name is specified with a matching capture group   # noqa: E501

        :return: The upstream_group_name of this UpstreamGroupMappingEntry.  # noqa: E501
        :rtype: str
        """
        return self._upstream_group_name

    @upstream_group_name.setter
    def upstream_group_name(self, upstream_group_name):
        """Sets the upstream_group_name of this UpstreamGroupMappingEntry.

        The name of the group in your upstream identity provider that you want to map. This can be in the form of a regular expression capture group. The example value will capture all groups starting with 'Company Team' and will use the value in the agilicus_group_name. For example Company Team HR Group will be mapped to Agilicus HR Group when the agilicus_group_name is specified with a matching capture group   # noqa: E501

        :param upstream_group_name: The upstream_group_name of this UpstreamGroupMappingEntry.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and upstream_group_name is None:  # noqa: E501
            raise ValueError("Invalid value for `upstream_group_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                upstream_group_name is not None and len(upstream_group_name) > 100):
            raise ValueError("Invalid value for `upstream_group_name`, length must be less than or equal to `100`")  # noqa: E501

        self._upstream_group_name = upstream_group_name

    @property
    def upstream_name_is_a_guid(self):
        """Gets the upstream_name_is_a_guid of this UpstreamGroupMappingEntry.  # noqa: E501

        Indicates that the supplied upstream_group_name will be found in the list of group IDs  # noqa: E501

        :return: The upstream_name_is_a_guid of this UpstreamGroupMappingEntry.  # noqa: E501
        :rtype: bool
        """
        return self._upstream_name_is_a_guid

    @upstream_name_is_a_guid.setter
    def upstream_name_is_a_guid(self, upstream_name_is_a_guid):
        """Sets the upstream_name_is_a_guid of this UpstreamGroupMappingEntry.

        Indicates that the supplied upstream_group_name will be found in the list of group IDs  # noqa: E501

        :param upstream_name_is_a_guid: The upstream_name_is_a_guid of this UpstreamGroupMappingEntry.  # noqa: E501
        :type: bool
        """

        self._upstream_name_is_a_guid = upstream_name_is_a_guid

    @property
    def agilicus_group_name(self):
        """Gets the agilicus_group_name of this UpstreamGroupMappingEntry.  # noqa: E501

        The name of the group in the Agilicus system that you want to map to. If the upstream_group_name is a capture group this field can contain those captured values. The match groups are specified by a { followed by the match number followed by a closing } ie {0}   # noqa: E501

        :return: The agilicus_group_name of this UpstreamGroupMappingEntry.  # noqa: E501
        :rtype: str
        """
        return self._agilicus_group_name

    @agilicus_group_name.setter
    def agilicus_group_name(self, agilicus_group_name):
        """Sets the agilicus_group_name of this UpstreamGroupMappingEntry.

        The name of the group in the Agilicus system that you want to map to. If the upstream_group_name is a capture group this field can contain those captured values. The match groups are specified by a { followed by the match number followed by a closing } ie {0}   # noqa: E501

        :param agilicus_group_name: The agilicus_group_name of this UpstreamGroupMappingEntry.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and agilicus_group_name is None:  # noqa: E501
            raise ValueError("Invalid value for `agilicus_group_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                agilicus_group_name is not None and len(agilicus_group_name) > 100):
            raise ValueError("Invalid value for `agilicus_group_name`, length must be less than or equal to `100`")  # noqa: E501

        self._agilicus_group_name = agilicus_group_name

    @property
    def group_org_id(self):
        """Gets the group_org_id of this UpstreamGroupMappingEntry.  # noqa: E501

        The org id that this group mapping applies to. Only mappings whose org id matches the org id that the user logged into will be mapped. If no scope is specified the org id of the issuer is assumed.  # noqa: E501

        :return: The group_org_id of this UpstreamGroupMappingEntry.  # noqa: E501
        :rtype: str
        """
        return self._group_org_id

    @group_org_id.setter
    def group_org_id(self, group_org_id):
        """Sets the group_org_id of this UpstreamGroupMappingEntry.

        The org id that this group mapping applies to. Only mappings whose org id matches the org id that the user logged into will be mapped. If no scope is specified the org id of the issuer is assumed.  # noqa: E501

        :param group_org_id: The group_org_id of this UpstreamGroupMappingEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                group_org_id is not None and len(group_org_id) > 40):
            raise ValueError("Invalid value for `group_org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._group_org_id = group_org_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpstreamGroupMappingEntry):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpstreamGroupMappingEntry):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class UpstreamGroupMappingSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'upstream_issuer': 'str',
        'org_id': 'str',
        'group_mappings': 'list[UpstreamGroupMappingEntry]',
        'excluded_groups': 'list[UpstreamGroupExcludedEntry]'
    }

    attribute_map = {
        'upstream_issuer': 'upstream_issuer',
        'org_id': 'org_id',
        'group_mappings': 'group_mappings',
        'excluded_groups': 'excluded_groups'
    }

    def __init__(self, upstream_issuer=None, org_id=None, group_mappings=None, excluded_groups=None, local_vars_configuration=None):  # noqa: E501
        """UpstreamGroupMappingSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._upstream_issuer = None
        self._org_id = None
        self._group_mappings = None
        self._excluded_groups = None
        self.discriminator = None

        self.upstream_issuer = upstream_issuer
        self.org_id = org_id
        if group_mappings is not None:
            self.group_mappings = group_mappings
        if excluded_groups is not None:
            self.excluded_groups = excluded_groups

    @property
    def upstream_issuer(self):
        """Gets the upstream_issuer of this UpstreamGroupMappingSpec.  # noqa: E501

        the upstream issuer that this mapping pertains to  # noqa: E501

        :return: The upstream_issuer of this UpstreamGroupMappingSpec.  # noqa: E501
        :rtype: str
        """
        return self._upstream_issuer

    @upstream_issuer.setter
    def upstream_issuer(self, upstream_issuer):
        """Sets the upstream_issuer of this UpstreamGroupMappingSpec.

        the upstream issuer that this mapping pertains to  # noqa: E501

        :param upstream_issuer: The upstream_issuer of this UpstreamGroupMappingSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and upstream_issuer is None:  # noqa: E501
            raise ValueError("Invalid value for `upstream_issuer`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                upstream_issuer is not None and len(upstream_issuer) > 100):
            raise ValueError("Invalid value for `upstream_issuer`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                upstream_issuer is not None and len(upstream_issuer) < 1):
            raise ValueError("Invalid value for `upstream_issuer`, length must be greater than or equal to `1`")  # noqa: E501

        self._upstream_issuer = upstream_issuer

    @property
    def org_id(self):
        """Gets the org_id of this UpstreamGroupMappingSpec.  # noqa: E501

        The org id corresponding to the issuer whose mapping is being updated  # noqa: E501

        :return: The org_id of this UpstreamGroupMappingSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this UpstreamGroupMappingSpec.

        The org id corresponding to the issuer whose mapping is being updated  # noqa: E501

        :param org_id: The org_id of this UpstreamGroupMappingSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._org_id = org_id

    @property
    def group_mappings(self):
        """Gets the group_mappings of this UpstreamGroupMappingSpec.  # noqa: E501

        The list of upstream group mappings  # noqa: E501

        :return: The group_mappings of this UpstreamGroupMappingSpec.  # noqa: E501
        :rtype: list[UpstreamGroupMappingEntry]
        """
        return self._group_mappings

    @group_mappings.setter
    def group_mappings(self, group_mappings):
        """Sets the group_mappings of this UpstreamGroupMappingSpec.

        The list of upstream group mappings  # noqa: E501

        :param group_mappings: The group_mappings of this UpstreamGroupMappingSpec.  # noqa: E501
        :type: list[UpstreamGroupMappingEntry]
        """

        self._group_mappings = group_mappings

    @property
    def excluded_groups(self):
        """Gets the excluded_groups of this UpstreamGroupMappingSpec.  # noqa: E501

        The list of upstream groups you wish to explicitly exclude from mapping. This is useful for a wildcard mapping   # noqa: E501

        :return: The excluded_groups of this UpstreamGroupMappingSpec.  # noqa: E501
        :rtype: list[UpstreamGroupExcludedEntry]
        """
        return self._excluded_groups

    @excluded_groups.setter
    def excluded_groups(self, excluded_groups):
        """Sets the excluded_groups of this UpstreamGroupMappingSpec.

        The list of upstream groups you wish to explicitly exclude from mapping. This is useful for a wildcard mapping   # noqa: E501

        :param excluded_groups: The excluded_groups of this UpstreamGroupMappingSpec.  # noqa: E501
        :type: list[UpstreamGroupExcludedEntry]
        """

        self._excluded_groups = excluded_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpstreamGroupMappingSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpstreamGroupMappingSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.sessions_spec import SessionsSpec  # noqa: E501
from agilicus_api.rest import ApiException

class TestSessionsSpec(unittest.TestCase):
    """SessionsSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SessionsSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.sessions_spec.SessionsSpec()  # noqa: E501
        if include_optional :
            return SessionsSpec(
                user_id = 'asdfghjklmn123', 
                org_id = 'asdfghjklmn123', 
                revoked = False, 
                number_of_logins = 3, 
                number_of_failed_multi_factor_challenges = 3
            )
        else :
            return SessionsSpec(
                user_id = 'asdfghjklmn123',
                org_id = 'asdfghjklmn123',
        )

    def testSessionsSpec(self):
        """Test SessionsSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ResourceRoleSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'resource_type': 'str',
        'role_name': 'str',
        'description': 'str'
    }

    attribute_map = {
        'resource_type': 'resource_type',
        'role_name': 'role_name',
        'description': 'description'
    }

    def __init__(self, resource_type=None, role_name=None, description=None, local_vars_configuration=None):  # noqa: E501
        """ResourceRoleSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._resource_type = None
        self._role_name = None
        self._description = None
        self.discriminator = None

        self.resource_type = resource_type
        self.role_name = role_name
        if description is not None:
            self.description = description

    @property
    def resource_type(self):
        """Gets the resource_type of this ResourceRoleSpec.  # noqa: E501

        The type of the resource referred to by `resource_id`.  # noqa: E501

        :return: The resource_type of this ResourceRoleSpec.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ResourceRoleSpec.

        The type of the resource referred to by `resource_id`.  # noqa: E501

        :param resource_type: The resource_type of this ResourceRoleSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and resource_type is None:  # noqa: E501
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501
        allowed_values = ["fileshare", "application_service"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def role_name(self):
        """Gets the role_name of this ResourceRoleSpec.  # noqa: E501

        A short descriptive name used to identify the role. Unique per resource_type.   # noqa: E501

        :return: The role_name of this ResourceRoleSpec.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this ResourceRoleSpec.

        A short descriptive name used to identify the role. Unique per resource_type.   # noqa: E501

        :param role_name: The role_name of this ResourceRoleSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and role_name is None:  # noqa: E501
            raise ValueError("Invalid value for `role_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                role_name is not None and len(role_name) > 40):
            raise ValueError("Invalid value for `role_name`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                role_name is not None and len(role_name) < 1):
            raise ValueError("Invalid value for `role_name`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                role_name is not None and not re.search(r'[a-zA-Z0-9-_:]+', role_name)):  # noqa: E501
            raise ValueError(r"Invalid value for `role_name`, must be a follow pattern or equal to `/[a-zA-Z0-9-_:]+/`")  # noqa: E501

        self._role_name = role_name

    @property
    def description(self):
        """Gets the description of this ResourceRoleSpec.  # noqa: E501

        A brief description of the role detailing the purpose of the role and what sort of permissions it grants.   # noqa: E501

        :return: The description of this ResourceRoleSpec.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ResourceRoleSpec.

        A brief description of the role detailing the purpose of the role and what sort of permissions it grants.   # noqa: E501

        :param description: The description of this ResourceRoleSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 100):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and not re.search(r'[a-zA-Z0-9-_:]+', description)):  # noqa: E501
            raise ValueError(r"Invalid value for `description`, must be a follow pattern or equal to `/[a-zA-Z0-9-_:]+/`")  # noqa: E501

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceRoleSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResourceRoleSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.mfa_challenge_question import MFAChallengeQuestion  # noqa: E501
from agilicus_api.rest import ApiException

class TestMFAChallengeQuestion(unittest.TestCase):
    """MFAChallengeQuestion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MFAChallengeQuestion
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.mfa_challenge_question.MFAChallengeQuestion()  # noqa: E501
        if include_optional :
            return MFAChallengeQuestion(
                input = agilicus_api.models.mfa_challenge_question_input.MFAChallengeQuestionInput(
                    login_info = agilicus_api.models.mfa_challenge_question_login_info.MFAChallengeQuestionLoginInfo(
                        user_preference = 'organisation_policy', 
                        client_id = 'app-1', 
                        client_guid = 'absjfladasdf23', 
                        issuer_org_id = 'absjfladasdf23', 
                        issuer_guid = 'absjfladasdf23', 
                        org_id = 'absjfladasdf23', 
                        user_id = 'jjkkGmwB9oTJWDjIglTU', 
                        user_object = agilicus_api.models.user_summary.UserSummary(
                            id = '123', 
                            external_id = '123', 
                            enabled = False, 
                            status = 'active', 
                            first_name = 'Alice', 
                            last_name = 'Kim', 
                            email = 'foo@example.com', 
                            provider = 'Google', 
                            roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                            org_id = '123', 
                            created = '2015-07-07T15:49:51.230+02:00', 
                            updated = '2015-07-07T15:49:51.230+02:00', 
                            auto_created = True, 
                            upstream_user_identities = [
                                agilicus_api.models.upstream_user_identity.UpstreamUserIdentity(
                                    metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                                    spec = agilicus_api.models.upstream_user_identity_spec.UpstreamUserIdentitySpec(
                                        upstream_user_id = 'aa-bb-cc-11-22-33', 
                                        upstream_idp_id = 'https://auth.cloud.egov.city', 
                                        local_user_id = 'tuU7smH86zAXMl76sua6xQ', ), )
                                ], 
                            cascade = True, ), 
                        login_session = agilicus_api.models.login_session.LoginSession(
                            session_id = 'abc123iamaguid', 
                            number_of_logins = 3, 
                            number_of_failed_multi_factor_challenges = 3, 
                            single_sign_on_time = '2015-07-07T15:49:51.230+02:00', 
                            user_is_authenticated = True, 
                            user_is_authenticated_by_upstream = True, 
                            user_is_authenticated_by_cache = True, ), 
                        upstream_idp = 'city-adfs', 
                        ip_address = '127.0.0.1', 
                        amr_claim_present = True, 
                        last_mfa_login = '2015-07-07T15:49:51.230+02:00', 
                        user_mfa_preferences = [
                            agilicus_api.models.mfa_challenge_method.MFAChallengeMethod(
                                spec = agilicus_api.models.mfa_challenge_method_spec.MFAChallengeMethodSpec(
                                    priority = 1, 
                                    challenge_type = '0', 
                                    endpoint = '0', 
                                    origin = 'agilicus.cloud', 
                                    nickname = '0', 
                                    enabled = True, ), )
                            ], ), )
            )
        else :
            return MFAChallengeQuestion(
                input = agilicus_api.models.mfa_challenge_question_input.MFAChallengeQuestionInput(
                    login_info = agilicus_api.models.mfa_challenge_question_login_info.MFAChallengeQuestionLoginInfo(
                        user_preference = 'organisation_policy', 
                        client_id = 'app-1', 
                        client_guid = 'absjfladasdf23', 
                        issuer_org_id = 'absjfladasdf23', 
                        issuer_guid = 'absjfladasdf23', 
                        org_id = 'absjfladasdf23', 
                        user_id = 'jjkkGmwB9oTJWDjIglTU', 
                        user_object = agilicus_api.models.user_summary.UserSummary(
                            id = '123', 
                            external_id = '123', 
                            enabled = False, 
                            status = 'active', 
                            first_name = 'Alice', 
                            last_name = 'Kim', 
                            email = 'foo@example.com', 
                            provider = 'Google', 
                            roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                            org_id = '123', 
                            created = '2015-07-07T15:49:51.230+02:00', 
                            updated = '2015-07-07T15:49:51.230+02:00', 
                            auto_created = True, 
                            upstream_user_identities = [
                                agilicus_api.models.upstream_user_identity.UpstreamUserIdentity(
                                    metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                                    spec = agilicus_api.models.upstream_user_identity_spec.UpstreamUserIdentitySpec(
                                        upstream_user_id = 'aa-bb-cc-11-22-33', 
                                        upstream_idp_id = 'https://auth.cloud.egov.city', 
                                        local_user_id = 'tuU7smH86zAXMl76sua6xQ', ), )
                                ], 
                            cascade = True, ), 
                        login_session = agilicus_api.models.login_session.LoginSession(
                            session_id = 'abc123iamaguid', 
                            number_of_logins = 3, 
                            number_of_failed_multi_factor_challenges = 3, 
                            single_sign_on_time = '2015-07-07T15:49:51.230+02:00', 
                            user_is_authenticated = True, 
                            user_is_authenticated_by_upstream = True, 
                            user_is_authenticated_by_cache = True, ), 
                        upstream_idp = 'city-adfs', 
                        ip_address = '127.0.0.1', 
                        amr_claim_present = True, 
                        last_mfa_login = '2015-07-07T15:49:51.230+02:00', 
                        user_mfa_preferences = [
                            agilicus_api.models.mfa_challenge_method.MFAChallengeMethod(
                                spec = agilicus_api.models.mfa_challenge_method_spec.MFAChallengeMethodSpec(
                                    priority = 1, 
                                    challenge_type = '0', 
                                    endpoint = '0', 
                                    origin = 'agilicus.cloud', 
                                    nickname = '0', 
                                    enabled = True, ), )
                            ], ), ),
        )

    def testMFAChallengeQuestion(self):
        """Test MFAChallengeQuestion"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class WebAuthNEnrollmentStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'challenge': 'str',
        'credential_id': 'str',
        'transports': 'list[str]'
    }

    attribute_map = {
        'challenge': 'challenge',
        'credential_id': 'credential_id',
        'transports': 'transports'
    }

    def __init__(self, challenge=None, credential_id=None, transports=None, local_vars_configuration=None):  # noqa: E501
        """WebAuthNEnrollmentStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._challenge = None
        self._credential_id = None
        self._transports = None
        self.discriminator = None

        if challenge is not None:
            self.challenge = challenge
        if credential_id is not None:
            self.credential_id = credential_id
        if transports is not None:
            self.transports = transports

    @property
    def challenge(self):
        """Gets the challenge of this WebAuthNEnrollmentStatus.  # noqa: E501

        An opaque string used to challenge a user attempting to login using WebAuthN. The second factor device will return a signed version of this challenge to indicate that the user should be allowed to proceed.   # noqa: E501

        :return: The challenge of this WebAuthNEnrollmentStatus.  # noqa: E501
        :rtype: str
        """
        return self._challenge

    @challenge.setter
    def challenge(self, challenge):
        """Sets the challenge of this WebAuthNEnrollmentStatus.

        An opaque string used to challenge a user attempting to login using WebAuthN. The second factor device will return a signed version of this challenge to indicate that the user should be allowed to proceed.   # noqa: E501

        :param challenge: The challenge of this WebAuthNEnrollmentStatus.  # noqa: E501
        :type: str
        """

        self._challenge = challenge

    @property
    def credential_id(self):
        """Gets the credential_id of this WebAuthNEnrollmentStatus.  # noqa: E501

        A probabilistically-unique byte sequence identifying a public key credential source and its authentication assertions. See https://www.w3.org/TR/webauthn/#credential-id for more details   # noqa: E501

        :return: The credential_id of this WebAuthNEnrollmentStatus.  # noqa: E501
        :rtype: str
        """
        return self._credential_id

    @credential_id.setter
    def credential_id(self, credential_id):
        """Sets the credential_id of this WebAuthNEnrollmentStatus.

        A probabilistically-unique byte sequence identifying a public key credential source and its authentication assertions. See https://www.w3.org/TR/webauthn/#credential-id for more details   # noqa: E501

        :param credential_id: The credential_id of this WebAuthNEnrollmentStatus.  # noqa: E501
        :type: str
        """

        self._credential_id = credential_id

    @property
    def transports(self):
        """Gets the transports of this WebAuthNEnrollmentStatus.  # noqa: E501

        List of supported transports for this enrolled credential  # noqa: E501

        :return: The transports of this WebAuthNEnrollmentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._transports

    @transports.setter
    def transports(self, transports):
        """Sets the transports of this WebAuthNEnrollmentStatus.

        List of supported transports for this enrolled credential  # noqa: E501

        :param transports: The transports of this WebAuthNEnrollmentStatus.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["internal", "ble", "nfc", "usb"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(transports).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `transports` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(transports) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._transports = transports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebAuthNEnrollmentStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebAuthNEnrollmentStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.upstream_group_mapping import UpstreamGroupMapping  # noqa: E501
from agilicus_api.rest import ApiException

class TestUpstreamGroupMapping(unittest.TestCase):
    """UpstreamGroupMapping unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UpstreamGroupMapping
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.upstream_group_mapping.UpstreamGroupMapping()  # noqa: E501
        if include_optional :
            return UpstreamGroupMapping(
                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                spec = agilicus_api.models.upstream_group_mapping_spec.UpstreamGroupMappingSpec(
                    upstream_issuer = 'https://login.microsoftonline.com/c945d377-ea94-4a7d-9c83-0615e7ff0022/v2.0', 
                    org_id = 'asdfg123hjkl', 
                    group_mappings = [
                        agilicus_api.models.upstream_group_mapping_entry.UpstreamGroupMappingEntry(
                            priority = 1, 
                            upstream_group_name = 'Company Team (.*)', 
                            upstream_name_is_a_guid = False, 
                            agilicus_group_name = 'Agilicus {0}', 
                            group_org_id = 'asdfg123hjkl', )
                        ], 
                    excluded_groups = [
                        agilicus_api.models.upstream_group_excluded_entry.UpstreamGroupExcludedEntry(
                            upstream_group_name = 'Admin*', 
                            upstream_name_is_a_guid = False, )
                        ], )
            )
        else :
            return UpstreamGroupMapping(
                spec = agilicus_api.models.upstream_group_mapping_spec.UpstreamGroupMappingSpec(
                    upstream_issuer = 'https://login.microsoftonline.com/c945d377-ea94-4a7d-9c83-0615e7ff0022/v2.0', 
                    org_id = 'asdfg123hjkl', 
                    group_mappings = [
                        agilicus_api.models.upstream_group_mapping_entry.UpstreamGroupMappingEntry(
                            priority = 1, 
                            upstream_group_name = 'Company Team (.*)', 
                            upstream_name_is_a_guid = False, 
                            agilicus_group_name = 'Agilicus {0}', 
                            group_org_id = 'asdfg123hjkl', )
                        ], 
                    excluded_groups = [
                        agilicus_api.models.upstream_group_excluded_entry.UpstreamGroupExcludedEntry(
                            upstream_group_name = 'Admin*', 
                            upstream_name_is_a_guid = False, )
                        ], ),
        )

    def testUpstreamGroupMapping(self):
        """Test UpstreamGroupMapping"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.upstream_group_mapping_spec import UpstreamGroupMappingSpec  # noqa: E501
from agilicus_api.rest import ApiException

class TestUpstreamGroupMappingSpec(unittest.TestCase):
    """UpstreamGroupMappingSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UpstreamGroupMappingSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.upstream_group_mapping_spec.UpstreamGroupMappingSpec()  # noqa: E501
        if include_optional :
            return UpstreamGroupMappingSpec(
                upstream_issuer = 'https://login.microsoftonline.com/c945d377-ea94-4a7d-9c83-0615e7ff0022/v2.0', 
                org_id = 'asdfg123hjkl', 
                group_mappings = [
                    agilicus_api.models.upstream_group_mapping_entry.UpstreamGroupMappingEntry(
                        priority = 1, 
                        upstream_group_name = 'Company Team (.*)', 
                        upstream_name_is_a_guid = False, 
                        agilicus_group_name = 'Agilicus {0}', 
                        group_org_id = 'asdfg123hjkl', )
                    ], 
                excluded_groups = [
                    agilicus_api.models.upstream_group_excluded_entry.UpstreamGroupExcludedEntry(
                        upstream_group_name = 'Admin*', 
                        upstream_name_is_a_guid = False, )
                    ]
            )
        else :
            return UpstreamGroupMappingSpec(
                upstream_issuer = 'https://login.microsoftonline.com/c945d377-ea94-4a7d-9c83-0615e7ff0022/v2.0',
                org_id = 'asdfg123hjkl',
        )

    def testUpstreamGroupMappingSpec(self):
        """Test UpstreamGroupMappingSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_upstream_group_mapping import ListUpstreamGroupMapping  # noqa: E501
from agilicus_api.rest import ApiException

class TestListUpstreamGroupMapping(unittest.TestCase):
    """ListUpstreamGroupMapping unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListUpstreamGroupMapping
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_upstream_group_mapping.ListUpstreamGroupMapping()  # noqa: E501
        if include_optional :
            return ListUpstreamGroupMapping(
                upstream_group_mapping = [
                    agilicus_api.models.upstream_group_mapping.UpstreamGroupMapping(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.upstream_group_mapping_spec.UpstreamGroupMappingSpec(
                            upstream_issuer = 'https://login.microsoftonline.com/c945d377-ea94-4a7d-9c83-0615e7ff0022/v2.0', 
                            org_id = 'asdfg123hjkl', 
                            group_mappings = [
                                agilicus_api.models.upstream_group_mapping_entry.UpstreamGroupMappingEntry(
                                    priority = 1, 
                                    upstream_group_name = 'Company Team (.*)', 
                                    upstream_name_is_a_guid = False, 
                                    agilicus_group_name = 'Agilicus {0}', 
                                    group_org_id = 'asdfg123hjkl', )
                                ], 
                            excluded_groups = [
                                agilicus_api.models.upstream_group_excluded_entry.UpstreamGroupExcludedEntry(
                                    upstream_group_name = 'Admin*', 
                                    upstream_name_is_a_guid = False, )
                                ], ), )
                    ], 
                limit = 56
            )
        else :
            return ListUpstreamGroupMapping(
                upstream_group_mapping = [
                    agilicus_api.models.upstream_group_mapping.UpstreamGroupMapping(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.upstream_group_mapping_spec.UpstreamGroupMappingSpec(
                            upstream_issuer = 'https://login.microsoftonline.com/c945d377-ea94-4a7d-9c83-0615e7ff0022/v2.0', 
                            org_id = 'asdfg123hjkl', 
                            group_mappings = [
                                agilicus_api.models.upstream_group_mapping_entry.UpstreamGroupMappingEntry(
                                    priority = 1, 
                                    upstream_group_name = 'Company Team (.*)', 
                                    upstream_name_is_a_guid = False, 
                                    agilicus_group_name = 'Agilicus {0}', 
                                    group_org_id = 'asdfg123hjkl', )
                                ], 
                            excluded_groups = [
                                agilicus_api.models.upstream_group_excluded_entry.UpstreamGroupExcludedEntry(
                                    upstream_group_name = 'Admin*', 
                                    upstream_name_is_a_guid = False, )
                                ], ), )
                    ],
                limit = 56,
        )

    def testListUpstreamGroupMapping(self):
        """Test ListUpstreamGroupMapping"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.connector_status import ConnectorStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestConnectorStatus(unittest.TestCase):
    """ConnectorStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ConnectorStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.connector_status.ConnectorStatus()  # noqa: E501
        if include_optional :
            return ConnectorStatus(
                application_services = [
                    agilicus_api.models.application_service.ApplicationService(
                        created = '2015-07-07T15:49:51.230+02:00', 
                        id = '123', 
                        name = 'my-local-service', 
                        org_id = '0', 
                        hostname = 'db.example.com', 
                        ipv4_addresses = [
                            '192.0.2.1'
                            ], 
                        name_resolution = 'static', 
                        port = 56, 
                        protocol = 'tcp', 
                        assignments = [
                            agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                app_id = '0', 
                                environment_name = '0', 
                                org_id = '0', )
                            ], 
                        updated = '2015-07-07T15:49:51.230+02:00', 
                        service_type = 'vpn', 
                        service_protocol_type = 'ip', 
                        tls_enabled = True, 
                        tls_verify = True, 
                        connector_id = '123', 
                        connection_uri = '0', )
                    ], 
                service_account_id = '0', 
                stats = agilicus_api.models.connector_stats.ConnectorStats(
                    metadata = agilicus_api.models.connector_stats_metadata.ConnectorStatsMetadata(
                        creation_time = '2020-07-07T15:40:46.010Z', 
                        collection_time = '2020-07-07T15:49:51.230Z', 
                        receipt_time = '2020-07-07T15:49:51.530Z', ), 
                    overall_status = 'good', )
            )
        else :
            return ConnectorStatus(
        )

    def testConnectorStatus(self):
        """Test ConnectorStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
